@@ -16,6 +16,9 @@ INSTALLED_APPS = getattr(settings, "INSTALLED_APPS", [])
 # Number of records to display per page for pagination
 RECORD_PER_PAGE_PAGINATION = getattr(settings, "RESULTS_PER_PAGE", 10)
 
+# Number of files to display per page for pagination
+FILE_PER_PAGE_PAGINATION = getattr(settings, "RESULTS_PER_PAGE", 10)
+
 # Number of records to display per page for pagination
 QUERY_PER_PAGE_PAGINATION = getattr(settings, "RESULTS_PER_PAGE", 10)
 
